@@ -41,7 +41,6 @@ class TrellisImageTo3DPipeline(Pipeline):
         self.slat_sampler_params = {}
         self.slat_normalization = slat_normalization
         self.rembg_session = None
-        self.path = None
         self._init_image_cond_model(image_cond_model)
 
     @staticmethod
@@ -67,8 +66,9 @@ class TrellisImageTo3DPipeline(Pipeline):
 
         cond_model_path = os.path.join(path, args['model_path'])
         new_pipeline._init_image_cond_model(args['image_cond_model'], cond_model_path)
-        self.path = path
-
+        
+        new_pipeline.path = path
+        
         return new_pipeline
     
     def _init_image_cond_model(self, name: str, model_path: str):
